#! /bin/sh
#----------------------------------------------------------------------------
# apache2 - Preinstallation
#
# Creation:     2005-02-17  MOU
# Last Update:  $Id: preinstall.sh 106137 2023-08-28 12:07:38Z schlotze $
#
# Copyright (c) 2005-2023 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

package_name=apache2
addparams=/etc/apache2/AddParams.conf
oldaddparams=/usr/local/apache2/conf/AddParams.conf
conffile=/etc/config.d/apache2
infofile=/var/install/packages/apache2
installfile=/var/run/apache2.install

# ---------------------------------------------------------------------------
# update system
# ---------------------------------------------------------------------------
if [ -f $oldaddparams ]
then
    cp $oldaddparams /tmp/AddParams.conf.SAVE
elif [ -f $addparams ]
then
    cp $addparams /tmp/AddParams.conf.SAVE
fi


installed=$(eisman check ${package_name} 2.0.20)

if [ "${installed}" = "new" ]
then
    /usr/sbin/service stop apache2

    filelist=/etc/filelist.d/${package_name}-files.txt
	while read id perm user group package file
	do
	    case ${id} in
	    b|u|s)
	        # remove program files
	        if [ "${file}" != "tmp/install.sh" \
	          -a "${file}" != "tmp/preinstall.sh" ]
	        then
	            rm -f /${file}
	        fi
	        ;;	
	    f)
	        # remove directories
	        rmdir --ignore-fail-on-non-empty /${file} 2>/dev/null
	        ;;
	    esac
	done < ${filelist}
	
    #
    # remove enabled module config before update
    #
    for module in actions alias asis auth_basic auth_digest authn_anon authn_dbd authn_dbm authn_file authz_dbm authz_groupfile authz_host authz_owner authz_user autoindex cache cern_meta cgi dav dav_fs dbd deflate dir disk_cache dump_io env expires ext_filter filter headers ident imagemap include info log_config log_forensic mime mime_magic negotiation proxy proxy_ajp proxy_balancer proxy_connect proxy_ftp proxy_http rewrite setenvif speling ssl status substitute unique_id userdir usertrack version vhost_alias
    do
        rm -f /etc/apache2/mods-enabled/${module}.load
        rm -f /etc/apache2/mods-enabled/${module}.conf
    done   
fi

installed=$(eisman check ${package_name} 2.0.25)

if [ "${installed}" = "new" ]
then
    if [ -f /var/install/deinstall/${package_name} ]
    then
        sed -i '/etc\/check.d\/\${package_name}/d' /var/install/deinstall/${package_name}
    fi
fi


# ---------------------------------------------------------------------------
# remove obsolete files
# ---------------------------------------------------------------------------
rm -f /var/install/config.d/apache2-update-vhost.sh
rm -f /var/install/config.d/apache2.eis-config.sh


if [ -f /etc/init.d/${package_name} ]
then
     /usr/sbin/service stop ${package_name}
     /usr/sbin/service disable ${package_name}
     /usr/bin/rm -f /etc/rc2.d/*${package_name}
     /usr/bin/rm -f /etc/init.d/${package_name}
     /usr/sbin/service daemon-reload
     /usr/bin/sed -i '/^\/etc\/init.d\//d' /var/install/deinstall/${package_name}
     /usr/bin/sed -i '/^\/usr\/sbin\/service/d' /var/install/deinstall/${package_name}
fi

exit 0
#----------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------
