#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/apache2-update.sh - parameter update script
#
# Creation:     2006-07-31 mou
# Last Update:  $Id: apache2-update.sh 106137 2023-08-28 12:07:38Z schlotze $
#
# Copyright (c) 2006-2019 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

#exec 2> /tmp/apache2-update-base-trace$$.log
#set -x
### -------------------------------------------------------------------------
### major variables
### -------------------------------------------------------------------------
# presonal data
# -------------
my_name='Sebastian Scholze'
my_initial='schlotze'
my_copy="`date +%Y` ${my_name} <sebastian(at)eisfair(dot)org>"

# date settings
# -------------
datum_creation="2006-07-31"
datum_update=`date +%Y-%m-%d`

# name of the current package
# ---------------------------
packages_name=apache2

APACHE2_DATADIR='/var/'

### -------------------------------------------------------------------------
### include libs for using
### -------------------------------------------------------------------------
. /var/install/include/configlib     # configlib from eisfair
. /var/install/include/eislib
. /var/install/include/apache2lib

### -------------------------------------------------------------------------
### Set the default values for configuration
### ----------------------------------------
START_APACHE2='no'
APACHE2_PORT='80'
APACHE2_MPM='prefork'
APACHE2_SERVER_ADMIN='webmaster@foo.bar'
APACHE2_SERVER_NAME='eis.lan.fli4l'
APACHE2_SERVER_SIGNATURE='Off'
APACHE2_DOCUMENT_ROOT=${APACHE2_DATADIR}'www/htdocs'
APACHE2_DIRECTORY_INDEX='index.html index.htm'
APACHE2_HOSTNAME_LOOKUPS='yes'
APACHE2_VIEW_DIRECTORY_CONTENT='yes'
APACHE2_ACCESS_CONTROL_TYPE_ALL='yes'
APACHE2_ACCESS_CONTROL_TYPE_IP='no'
APACHE2_ACCESS_CONTROL_TYPE_HOST='no'
APACHE2_ACCESS_CONTROL_TYPE_LOCAL='no'
APACHE2_ACCESS_CONTROL_IP='192.168.6.1/24'
APACHE2_ACCESS_CONTROL_HOST='eis'
APACHE2_ENABLE_SSI='no'
APACHE2_ENABLE_HTTP2='no'
#----------------------------------------------------------------------------
# Error and Access Logs
#----------------------------------------------------------------------------
APACHE2_ERROR_LOG=${APACHE2_DATADIR}'www/log/error_log'
APACHE2_ACCESS_LOG=${APACHE2_DATADIR}'www/log/access_log'
#----------------------------------------------------------------------------
# Scrip-Aliases [DON'T FORGET TO APPEND A SLASH (/) AFTER PATHNAMES!]
#----------------------------------------------------------------------------
APACHE2_SCRIPT_ALIAS='/cgi-bin/'
APACHE2_SCRIPT_DIR=${APACHE2_DATADIR}'www/cgi-bin/'
#----------------------------------------------------------------------------
# Error Documents
#----------------------------------------------------------------------------
APACHE2_ERROR_DOCUMENT_N='0'
APACHE2_ERROR_DOCUMENT_1_ERROR='404'
APACHE2_ERROR_DOCUMENT_1_DOCUMENT='/404error.html'
#----------------------------------------------------------------------------
# Directory Settings + Alias
#----------------------------------------------------------------------------
APACHE2_DIR_N='2'
APACHE2_DIR_1_ACTIVE='yes'
APACHE2_DIR_1_ALIAS='yes'
APACHE2_DIR_1_ALIAS_NAME='/icons/'
APACHE2_DIR_1_PATH='/usr/share/apache2/icons/'
APACHE2_DIR_1_AUTH_NAME=''
APACHE2_DIR_1_AUTH_TYPE='Basic'
APACHE2_DIR_1_AUTH_N='0'
APACHE2_DIR_1_AUTH_1_USER=''
APACHE2_DIR_1_AUTH_1_PASS=''
APACHE2_DIR_1_ACCESS_CONTROL_TYPE_ALL='yes'
APACHE2_DIR_1_ACCESS_CONTROL_TYPE_IP='no'
APACHE2_DIR_1_ACCESS_CONTROL_TYPE_HOST='no'
APACHE2_DIR_1_ACCESS_CONTROL_TYPE_LOCAL='no'
APACHE2_DIR_1_ACCESS_CONTROL_IP='192.168.6.1/24'
APACHE2_DIR_1_ACCESS_CONTROL_HOST='eis'
APACHE2_DIR_1_CGI='none'
APACHE2_DIR_1_SSI='no'
APACHE2_DIR_1_VIEW_DIR_CONTENT='no'
APACHE2_DIR_1_WEBDAV='no'
APACHE2_DIR_2_ACTIVE='no'
APACHE2_DIR_2_ALIAS='no'
APACHE2_DIR_2_ALIAS_NAME=''
APACHE2_DIR_2_PATH=${APACHE2_DATADIR}'www/htdocs/geheim/'
APACHE2_DIR_2_AUTH_NAME='Members only!'
APACHE2_DIR_2_AUTH_TYPE='Basic'
APACHE2_DIR_2_AUTH_N='0'
APACHE2_DIR_2_AUTH_1_USER='user'
APACHE2_DIR_2_AUTH_1_PASS='secret'
APACHE2_DIR_2_ACCESS_CONTROL_TYPE_ALL='yes'
APACHE2_DIR_2_ACCESS_CONTROL_TYPE_IP='no'
APACHE2_DIR_2_ACCESS_CONTROL_TYPE_HOST='no'
APACHE2_DIR_2_ACCESS_CONTROL_TYPE_LOCAL='no'
APACHE2_DIR_2_ACCESS_CONTROL_IP='192.168.6.1/24'
APACHE2_DIR_2_ACCESS_CONTROL_HOST='eis'
APACHE2_DIR_2_CGI='none'
APACHE2_DIR_2_SSI='no'
APACHE2_DIR_2_VIEW_DIR_CONTENT='no'
APACHE2_DIR_2_WEBDAV='no'
#----------------------------------------------------------------------------
# SSL
#----------------------------------------------------------------------------
APACHE2_SSL='no'
APACHE2_SSL_PORT='443'
APACHE2_SSL_LOGDIR=${APACHE2_DATADIR}'www/log/'
APACHE2_SSL_OCSP='no'
#----------------------------------------------------------------------------
# Settings for Log-file handling
#----------------------------------------------------------------------------
APACHE2_LOG_LEVEL='warn'
APACHE2_LOG_COUNT='10'
APACHE2_LOG_INTERVAL='weekly'
#----------------------------------------------------------------------------
# Settings for performance tuning
#----------------------------------------------------------------------------
APACHE2_MAX_KEEP_ALIVE_TIMEOUT='15'
APACHE2_MAX_KEEP_ALIVE_REQUESTS='100'
APACHE2_MAX_CLIENTS='250'
APACHE2_MAX_REQUESTS_PER_CHILD='1000'
#----------------------------------------------------------------------------
# Settings for VHost
#----------------------------------------------------------------------------
APACHE2_VHOST_N='1'
APACHE2_VHOST_1_ACTIVE='no'
APACHE2_VHOST_1_IP='*'
APACHE2_VHOST_1_PORT='80'
APACHE2_VHOST_1_SERVER_NAME='foo'
APACHE2_VHOST_1_SERVER_ALIAS='*.foo'
APACHE2_VHOST_1_SERVER_ADMIN='webmaster@foo.bar'
APACHE2_VHOST_1_DOCUMENT_ROOT=${APACHE2_DATADIR}'www/foo/htdocs'
APACHE2_VHOST_1_SCRIPT_ALIAS='/cgi-bin/'
APACHE2_VHOST_1_SCRIPT_DIR=${APACHE2_DATADIR}'www/foo/cgi-bin/'
APACHE2_VHOST_1_ERROR_LOG=${APACHE2_DATADIR}'www/log/foo_error_log'
APACHE2_VHOST_1_ACCESS_LOG=${APACHE2_DATADIR}'www/log/foo_access_log'
APACHE2_VHOST_1_ACCESS_CONTROL_TYPE_ALL='yes'
APACHE2_VHOST_1_ACCESS_CONTROL_TYPE_IP='no'
APACHE2_VHOST_1_ACCESS_CONTROL_TYPE_HOST='no'
APACHE2_VHOST_1_ACCESS_CONTROL_TYPE_LOCAL='no'
APACHE2_VHOST_1_ACCESS_CONTROL_IP='192.168.6.1/24'
APACHE2_VHOST_1_ACCESS_CONTROL_HOST='eis'
APACHE2_VHOST_1_VIEW_DIRECTORY_CONTENT='no'
APACHE2_VHOST_1_ENABLE_SSI='no'
APACHE2_VHOST_1_MOD_CACHE='no'
APACHE2_VHOST_1_DIR_N='1'
APACHE2_VHOST_1_DIR_1_ACTIVE='no'
APACHE2_VHOST_1_DIR_1_ALIAS='no'
APACHE2_VHOST_1_DIR_1_ALIAS_NAME=''
APACHE2_VHOST_1_DIR_1_PATH=${APACHE2_DATADIR}'www/htdocs/geheim'
APACHE2_VHOST_1_DIR_1_AUTH_NAME='Members only!'
APACHE2_VHOST_1_DIR_1_AUTH_TYPE='Basic'
APACHE2_VHOST_1_DIR_1_AUTH_N='0'
APACHE2_VHOST_1_DIR_1_AUTH_1_USER='user'
APACHE2_VHOST_1_DIR_1_AUTH_1_PASS='secret'
APACHE2_VHOST_1_DIR_1_ACCESS_CONTROL_TYPE_ALL='yes'
APACHE2_VHOST_1_DIR_1_ACCESS_CONTROL_TYPE_IP='no'
APACHE2_VHOST_1_DIR_1_ACCESS_CONTROL_TYPE_HOST='no'
APACHE2_VHOST_1_DIR_1_ACCESS_CONTROL_TYPE_LOCAL='no'
APACHE2_VHOST_1_DIR_1_ACCESS_CONTROL_IP='192.168.6.1/24'
APACHE2_VHOST_1_DIR_1_ACCESS_CONTROL_HOST='eis'
APACHE2_VHOST_1_DIR_1_CGI='none'
APACHE2_VHOST_1_DIR_1_SSI='no'
APACHE2_VHOST_1_DIR_1_VIEW_DIR_CONTENT='no'
APACHE2_VHOST_1_DIR_1_WEBDAV='no'
APACHE2_VHOST_1_SSL='no'
APACHE2_VHOST_1_SSL_PORT='443'
APACHE2_VHOST_1_SSL_USESTS='no'
APACHE2_VHOST_1_SSL_USESTS_SUBDOMAIN='no'
APACHE2_VHOST_1_SSL_FORCE='no'
APACHE2_VHOST_1_SSL_CERT_NAME='apache'
#----------------------------------------------------------------------------
# Settings for apache modules
#----------------------------------------------------------------------------
APACHE2_MOD_CACHE='no'
APACHE2_MOD_COMPAT='yes'
#----------------------------------------------------------------------------
# Settings for Header
#----------------------------------------------------------------------------
APACHE2_HEADER_NOSNIFF='no'
APACHE2_HEADER_XSSPROTECTION='no'
APACHE2_HEADER_SAMEORIGIN='no'

### -------------------------------------------------------------------------
### read old configuration and rename old variables
### -------------------------------------------------------------------------
rename_old_variables()
{
    renamed=0
    #mecho --info "renaming parameter(s) ..."
    # read old values
    if [ -f /etc/config.d/${packages_name} ]
    then
        . /etc/config.d/${packages_name}

        # 1.1.6
        if [ -z "`grep ^APACHE2_SCRIPT_DIR /etc/config.d/$packages_name`" ]
        then
            APACHE2_SCRIPT_DIR="$APACHE2_SCRIPT_ALIAS"
            APACHE2_SCRIPT_ALIAS="/cgi-bin/"
            #mecho "- APACHE2_SCRIPT_ALIAS -> APACHE2_SCRIPT_DIR"
            renamed=1
        fi
        if [ ! -z "`grep ^APACHE2_ALIAS_N /etc/config.d/$packages_name`" ]
        then
            idx=`expr $APACHE2_DIR_N + 0`
            aliasIdx=1
            count=`expr $APACHE2_ALIAS_N + $idx - 1`
            lastDirNo=`expr $APACHE2_DIR_N + 1`

            while [ $idx -le $count ]
            do
                eval "APACHE2_DIR_"$lastDirNo"_ALIAS"='no'
                eval "APACHE2_DIR_"$lastDirNo"_ALIAS_NAME"='$APACHE2_ALIAS_'$aliasIdx'_ALIAS'
                eval "APACHE2_DIR_"$lastDirNo"_PATH"='$APACHE2_ALIAS_'$aliasIdx'_DIRECTORY'
                eval "APACHE2_DIR_"$lastDirNo"_AUTH_NAME"=''
                eval "APACHE2_DIR_"$lastDirNo"_AUTH_N"='0'
                eval "APACHE2_DIR_"$lastDirNo"_AUTH_1_USER"=''
                eval "APACHE2_DIR_"$lastDirNo"_AUTH_1_PASS"=''
                eval "APACHE2_DIR_"$lastDirNo"_ACCESS_CONTROL"='all'
                eval "APACHE2_DIR_"$lastDirNo"_CGI"='none'
                eval "APACHE2_DIR_"$lastDirNo"_SSI"='no'
                eval "APACHE2_DIR_"$lastDirNo"_VIEW_DIR_CONTENT"='no'
                eval "APACHE2_DIR_"$lastDirNo"_WEBDAV"='no'
                lastDirNo=`expr $lastDirNo + 1`
                idx=`expr $idx + 1`
                aliasIdx=`expr $aliasIdx + 1`
            done
            APACHE2_DIR_N=`expr $count + 1`
            #mecho "- APACHE2_ALIAS_N -> APACHE2_DIR_%_ALIAS, APACHE2_DIR_%_ALIAS_NAME"
            renamed=1
        fi
        # OCSP
        if [ -n "`grep ^APACHE2_SSL_OSCP /etc/config.d/$packages_name`" ]
        then
            APACHE2_SSL_OCSP="$APACHE2_SSL_OSCP"
            renamed=1
        fi

    fi

    if [ $renamed -eq 1 ]
    then
        mecho --info "... read documentation for renamed parameter(s)!"
        #anykey
    fi
}

remove_old_module_configs ()
{
    cd /etc/apache2/mods-available
    rm -f mem_cache.*
    rm -f authn_default.*
    rm -f authz_default.*
    rm -f authn_alias.*
    rm -f example.*
    cd /etc/apache2/mods-enabled
    rm -f mem_cache.*
    rm -f authn_default.*
    rm -f authz_default.*
    rm -f authn_alias.*
    rm -f example.*
}        

remove_old_modules ()
{
    cd /usr/lib/apache2/modules
    rm -f mod_authn_alias.so
    rm -f mod_authn_default.so
    rm -f mod_authz_default.so
    rm -f mod_disk_cache.so
    rm -f mod_example.so
    rm -f mod_mem_cache.so
}   
### -------------------------------------------------------------------------
### read old configuration and rename old variables
### -------------------------------------------------------------------------
add_variables ()
{
    added=0
    #mecho --info "adding new parameter(s) ..."
    
    # v1.1.0
    if [ -f /etc/config.d/$packages_name ]
    then 
        if [ -z "`grep ^APACHE2_LOG_COUNT /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_LOG_COUNT='10'"
            #mecho "- APACHE2_LOG_INTERVAL='weekly'"
            added=1
        fi
    fi

    # v1.3.0
    if [ -f /etc/config.d/$packages_name ]
    then 
        if [ -z "`grep ^APACHE2_LOG_LEVEL /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_LOG_LEVEL='warn'"
            added=1
        fi
        if [ -z "`grep ^APACHE2_SERVER_SIGNATURE /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_SERVER_SIGNATURE='On'"
            added=1
        fi
        if [ -z "`grep ^APACHE2_MAX_KEEP_ALIVE_TIMEOUT /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_MAX_KEEP_ALIVE_TIMEOUT='15'"
            added=1
        fi
        if [ -z "`grep ^APACHE2_MAX_KEEP_ALIVE_REQUESTS /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_MAX_KEEP_ALIVE_REQUESTS='100'"
            added=1
        fi
        if [ -z "`grep ^APACHE2_MAX_CLIENTS /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_MAX_CLIENTS='250'"
            added=1
        fi
        if [ -z "`grep ^APACHE2_MAX_REQUESTS_PER_CHILD /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_MAX_REQUESTS_PER_CHILD='10000'"
            added=1
        fi
        if [ -z "`grep ^APACHE2_SCRIPT_DIR /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_SCRIPT_ALIAS='/cgi-bin/'"
            added=1
        fi

        idx='1'
        count=`expr $APACHE2_DIR_N + 0`
        while [ $idx -le $count ]
        do
            eval tmpAlias='$APACHE2_DIR_'$idx'_ALIAS'
            eval tmpAliasName='$APACHE2_DIR_'$idx'_ALIAS_NAME'
            if [ -z "`grep ^APACHE2_DIR_${idx}_ALIAS /etc/config.d/$packages_name`" ]
            then
                if [ "$tmpAlias" != "yes" ]
                then
                    tmpAlias='no'
                    eval "APACHE2_DIR_"$idx"_ALIAS"='no'
                    eval "APACHE2_DIR_"$idx"_ALIAS_NAME"=''
                fi
                #mecho "- APACHE2_DIR_${idx}_ALIAS='$tmpAlias'"
                #mecho "- APACHE2_DIR_${idx}_ALIAS_NAME='$tmpAliasName'"
                added=1
            fi
            if [ -z "`grep ^APACHE2_DIR_${idx}_ACTIVE /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_DIR_"${idx}"_ACTIVE"='yes'
                #mecho "- APACHE2_DIR_${idx}_ACTIVE='yes'"
                added=1
            fi
            idx=`expr $idx + 1`
        done

        idx='1'
        count=`expr $APACHE2_VHOST_N + 0`
        while [ $idx -le $count ]
        do
            eval tmp='APACHE2_VHOST_'$idx'_DIR_N'
            if [ -z "`grep ^$tmp /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_VHOST_"$idx"_DIR_N"='0'
                eval "APACHE2_VHOST_"$idx"_DIR_1_ACTIVE"='no'
                eval "APACHE2_VHOST_"$idx"_DIR_1_ALIAS"='no'
                eval "APACHE2_VHOST_"$idx"_DIR_1_ALIAS_NAME"=''
                eval "APACHE2_VHOST_"$idx"_DIR_1_PATH"=${APACHE2_DATADIR}'www/htdocs/geheim'
                eval "APACHE2_VHOST_"$idx"_DIR_1_AUTH_NAME"='Members-only'
                eval "APACHE2_VHOST_"$idx"_DIR_1_AUTH_N"='0'
                eval "APACHE2_VHOST_"$idx"_DIR_1_AUTH_1_USER"='user'
                eval "APACHE2_VHOST_"$idx"_DIR_1_AUTH_1_PASS"='secret'
                eval "APACHE2_VHOST_"$idx"_DIR_1_ACCESS_CONTROL"='all'
                eval "APACHE2_VHOST_"$idx"_DIR_1_CGI"='none'
                eval "APACHE2_VHOST_"$idx"_DIR_1_SSI"='no'
                eval "APACHE2_VHOST_"$idx"_DIR_1_VIEW_DIR_CONTENT"='no'
                eval "APACHE2_VHOST_"$idx"_DIR_1_WEBDAV"='no'
                added=1
            fi
            idx=`expr $idx + 1`
        done
    fi

    # 1.3.2 & 1.4.3 (without mod_cache)
    if [ -f /etc/config.d/$packages_name ]
    then 
        idx='1'
        count=`expr $APACHE2_VHOST_N + 0`
        while [ $idx -le $count ]
        do
            eval tmp='APACHE2_VHOST_'$idx'_VIEW_DIRECTORY_CONTENT'
            if [ -z "`grep ^$tmp /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_VHOST_"$idx"_VIEW_DIRECTORY_CONTENT"='no'
                eval "APACHE2_VHOST_"$idx"_ENABLE_SSI"='no'
                #mecho "- APACHE2_VHOST_${idx}_VIEW_DIRECTORY_CONTENT='no'"
                #mecho "- APACHE2_VHOST_${idx}_ENABLE_SSI='no'"
                added=1
            fi 
            eval tmp='APACHE2_VHOST_'$idx'_MOD_CACHE'
            if [ -z "`grep ^$tmp /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_VHOST_"$idx"_MOD_CACHE"='no'
                #mecho "- APACHE2_VHOST_${idx}_MOD_CACHE='no'"
                added=1
            fi
            idx=`expr $idx + 1`
        done
    fi

    # 1.3.4
    if [ -f /etc/config.d/$packages_name ]
    then 
        if [ -z "`grep ^APACHE2_MOD_CACHE /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_MOD_CACHE='no'"
            added=1
        fi
    fi
        
    # 1.4.5
    if [ -f /etc/config.d/$packages_name ]
    then 
        idx='1'
        count=`expr $APACHE2_DIR_N + 0`
        while [ $idx -le $count ]
        do
            if [ -z "`grep ^APACHE2_DIR_${idx}_AUTH_TYPE /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_DIR_"$idx"_AUTH_TYPE"='Basic'
                added=1
            fi
            idx=`expr $idx + 1`
        done
        vidx='1'
        vcount=`expr $APACHE2_VHOST_N + 0`
        while [ $vidx -le $vcount ]
        do
            idx='1'
            eval tmpcount='$APACHE2_VHOST_'${vidx}'_DIR_N'
            count=`expr $tmpcount + 0`
            while [ $idx -le $count ]
            do
                if [ -z "`grep ^APACHE2_VHOST_${vidx}_DIR_${idx}_AUTH_TYPE /etc/config.d/$packages_name`" ]
                then
                    eval "APACHE2_VHOST_"$vidx"_DIR_"$idx"_AUTH_TYPE"='Basic'
                    added=1
                fi
                idx=`expr $idx + 1`
            done
            vidx=`expr $vidx + 1`
        done
    fi

    # 1.7.0
    if [ -f /etc/config.d/$packages_name ]
    then 
        if [ -z "`grep ^APACHE2_MOD_COMPAT /etc/config.d/$packages_name`" ]
        then
            #mecho "- APACHE2_MOD_COMPAT='no'"
            added=1
        fi
        idx='1'
        count=`expr $APACHE2_DIR_N + 0`
        while [ $idx -le $count ]
        do
            if [ -z "`grep ^APACHE2_DIR_${idx}_ACCESS_CONTROL_TYPE_ALL /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_DIR_"$idx"_ACCESS_CONTROL_TYPE_ALL"='yes'
                added=1
            fi
            idx=`expr $idx + 1`
        done
        vidx='1'
        vcount=`expr $APACHE2_VHOST_N + 0`
        while [ $vidx -le $vcount ]
        do
            if [ -z "`grep ^APACHE2_VHOST_${vidx}_ACCESS_CONTROL_TYPE_ALL /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_VHOST_"$vidx"_ACCESS_CONTROL_TYPE_ALL"='yes'
                added=1
            fi
            vidx=`expr $vidx + 1`
        done
        vidx='1'
        vcount=`expr $APACHE2_VHOST_N + 0`
        while [ $vidx -le $vcount ]
        do
            idx='1'
            eval tmpcount='$APACHE2_VHOST_'${vidx}'_DIR_N'
            count=`expr $tmpcount + 0`
            while [ $idx -le $count ]
            do
                if [ -z "`grep ^APACHE2_VHOST_${vidx}_DIR_${idx}_ACCESS_CONTROL_TYPE_ALL /etc/config.d/$packages_name`" ]
                then
                    eval "APACHE2_VHOST_"$vidx"_DIR_"$idx"_ACCESS_CONTROL_TYPE_ALL"='yes'
                    added=1
                fi
                idx=`expr $idx + 1`
            done
            vidx=`expr $vidx + 1`
        done
    fi
    
    # 1.9.0
    if [ -f /etc/config.d/$packages_name ]
    then 
        vidx='1'
        vcount=`expr $APACHE2_VHOST_N + 0`
        while [ $vidx -le $vcount ]
        do
            if [ -z "`grep ^APACHE2_VHOST_${vidx}_SSL_USESTS /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_VHOST_"$vidx"_SSL_USESTS"='no'
                added=1
            fi
            vidx=`expr $vidx + 1`
        done
    fi
    
    if [ -f /etc/config.d/$packages_name ]
    then 
        idx='1'
        count=`expr $APACHE2_VHOST_N + 0`
        while [ $idx -le $count ]
        do
            if [ -z "`grep ^APACHE2_VHOST_${idx}_SSL_USESTS_SUBDOMAIN /etc/config.d/$packages_name`" ]
            then
                eval "APACHE2_VHOST_"$idx"_SSL_USESTS_SUBDOMAIN"='no'
                added=1
            fi
            idx=`expr $idx + 1`
        done
    fi
    
    if [ ${added} -eq 1 ]
    then
        mecho --info "... read documentation for new parameter(s)!"
        #anykey
    fi
}

### -------------------------------------------------------------------------
### Write config and default files
### -------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    (
    #------------------------------------------------------------------------
    printgpl -conf "$packages_name" "$datum_creation" "schlotze" "2008-2010 Sebastian Scholze <sebastian@eisfair.org>"

    #------------------------------------------------------------------------
    printgroup  "Start Apache2 Webserver during startup"
    #------------------------------------------------------------------------
    printvar "START_APACHE2"         "Start the Apache Webserver"
    printvar ""                      "yes=ON / no=OFF (default)"
    printvar

    #------------------------------------------------------------------------
    printgroup  "General settings"
    #------------------------------------------------------------------------
    printvar "APACHE2_PORT"             "TCP/IP port"
    printvar
    printvar "APACHE2_SERVER_ADMIN"     "Email address of webmaster "
    printvar
    printvar "APACHE2_SERVER_NAME"      "FQND of the server e.g."
    printvar ""                         "meineis.eisfair.net"
    printvar "APACHE2_SERVER_SIGNATURE" "On/Off/Email"
    printvar
    printvar "APACHE2_DOCUMENT_ROOT"    "Web root "
    printvar

    #------------------------------------------------------------------------------
    printgroup "Gerneral SSL Settings"
    #------------------------------------------------------------------------------
    printvar "APACHE2_SSL"        "Start SSL-Engine?"
    printvar "APACHE2_SSL_PORT"   "Port on which SSL should run"
    printvar "APACHE2_MPM"        "MPM"
    printvar
    printvar "APACHE2_SSL_LOGDIR" "SSL error and access logfiles directory"
    printvar ""                   "!!!DON'T FORGET TO APPEND A SLASH!!!"
    printvar "APACHE2_SSL_OCSP"   "Use OCSP Stabling?"
    printvar

    #------------------------------------------------------------------------
    printgroup  "Special Settings"
    #------------------------------------------------------------------------
    printvar "APACHE2_DIRECTORY_INDEX"        "Default document"
    printvar
    printvar "APACHE2_HOSTNAME_LOOKUPS"       "Resolve IPs in logfile?"
    printvar
    printvar "APACHE2_VIEW_DIRECTORY_CONTENT" "If there's no index.html view files in dir"
    printvar
    printvar "APACHE2_ACCESS_CONTROL_TYPE_ALL" "Default setting is yes. Access ist granted for all"
    printvar "APACHE2_ACCESS_CONTROL_TYPE_IP"  "If set to yes, access is controlled via IPADDRESS and/or NETWORK"
    printvar "APACHE2_ACCESS_CONTROL_TYPE_HOST" "If set to yes, access is controlled via HOSTNAME"
    printvar "APACHE2_ACCESS_CONTROL_TYPE_LOCAL" "If set to yes, only localhost has access"
    printvar "APACHE2_ACCESS_CONTROL_IP"       ""
    printvar "APACHE2_ACCESS_CONTROL_HOST"     ""
    printvar
    printvar "APACHE2_ENABLE_SSI"             "Enable SSI 'yes' or 'no'"
    printvar
    printvar "APACHE2_ENABLE_HTTP2"           "Enable mod_http2 'yes' or 'no'"
    printvar

    #------------------------------------------------------------------------------
    printgroup "Error and Access Logs "
    #------------------------------------------------------------------------------
    printvar "APACHE2_ERROR_LOG"  "Error log file"
    printvar "APACHE2_ACCESS_LOG" "Access log file"
    printvar

    #------------------------------------------------------------------------------
    printgroup "Scrip Aliases [DON'T FORGET TO APPEND A SLASH (/) AFTER PATHNAMES!]"     #'
    #------------------------------------------------------------------------------
    printvar "APACHE2_SCRIPT_ALIAS"    ""
    printvar "APACHE2_SCRIPT_DIR"      "Root where to put the CGIs in"
    printvar

    #------------------------------------------------------------------------------
    printgroup "Error Documents"
    #------------------------------------------------------------------------------
    printvar "APACHE2_ERROR_DOCUMENT_N"          "no. costum of Error Documents"

    idx='1'
    count=`expr $APACHE2_ERROR_DOCUMENT_N + 1`

    while [ $idx -le $count ]
    do
        eval name='$APACHE2_ERROR_DOCUMENT_'$idx'_ERROR'
        if [ -n "$name" ] ; then
            printvar "APACHE2_ERROR_DOCUMENT_"$idx"_ERROR"    "HTTP-Error number"
            printvar "APACHE2_ERROR_DOCUMENT_"$idx"_DOCUMENT" "HTML-Document to view "
        fi
        idx=`expr $idx + 1`
    done

    printvar

    #------------------------------------------------------------------------------
    printgroup "Directory Settings + Aliases"
    #------------------------------------------------------------------------------
    printvar "APACHE2_DIR_N"                  "No. of dirs"

    idx='1'
    count=`expr $APACHE2_DIR_N + 1`

    while [ $idx -le $count ]
    do
        eval name='$APACHE2_DIR_'$idx'_PATH'
        if [ -n "$name" ] ; then
            printvar "APACHE2_DIR_"$idx"_ACTIVE"           "Dir Active? yes/no"
            eval tmpAlias='$APACHE2_DIR_'$idx'_ALIAS'
            if [ "$tmpAlias" = "" ] 
            then
                eval "APACHE2_DIR_"$idx"_ALIAS"='no'
                eval "APACHE2_DIR_"$idx"_ALIAS_NAME"=''
            fi
            printvar "APACHE2_DIR_"$idx"_ALIAS"            "Create an alias?"
            printvar "APACHE2_DIR_"$idx"_ALIAS_NAME"       "Name of alias"
            eval icon_path='${APACHE2_DIR_'$idx'_PATH}'
            if [ "${icon_path}" = "/usr/local/apache2/icons/" ]
            then
                eval APACHE2_DIR_${idx}_PATH="/usr/share/apache2/icons/"
            fi
            printvar "APACHE2_DIR_"$idx"_PATH"             "Name of 1. dir"
            printvar "APACHE2_DIR_"$idx"_AUTH_NAME"        "Name of the area to protect"
            printvar "APACHE2_DIR_"$idx"_AUTH_TYPE"        "Authentication type: Basic or Digest"
            printvar "APACHE2_DIR_"$idx"_AUTH_N"           "No. of usernames"

            idy='1'
            eval countauth='$APACHE2_DIR_'$idx'_AUTH_N'
            count2=`expr $countauth + 1`

            while [ $idy -le $count2 ]
            do
                eval auth='$APACHE2_DIR_'$idx'_AUTH_'$idy'_USER'
                if [ -n "$auth" ] ; then
                    printvar "APACHE2_DIR_"$idx"_AUTH_"$idy"_USER"      "User no. $idy."
                    printvar "APACHE2_DIR_"$idx"_AUTH_"$idy"_PASS"      "Password for user $idy."
                fi
                idy=`expr $idy + 1`
            done

            printvar "APACHE2_DIR_"$idx"_ACCESS_CONTROL_TYPE_ALL" "Default setting is yes. Access ist granted for all"
            printvar "APACHE2_DIR_"$idx"_ACCESS_CONTROL_TYPE_IP"  "If set to yes, access is controlled via IPADDRESS and/or NETWORK"
            printvar "APACHE2_DIR_"$idx"_ACCESS_CONTROL_TYPE_HOST" "If set to yes, access is controlled via HOSTNAME"
            printvar "APACHE2_DIR_"$idx"_ACCESS_CONTROL_TYPE_LOCAL" "If set to yes, only localhost has access"
            printvar "APACHE2_DIR_"$idx"_ACCESS_CONTROL_IP"       ""
            printvar "APACHE2_DIR_"$idx"_ACCESS_CONTROL_HOST"     ""
            printvar "APACHE2_DIR_"$idx"_CGI"              "!NOT YES! Possibilities are: 'none' '.pl' '.cgi'"
            printvar "APACHE2_DIR_"$idx"_SSI"              "Allow Server Side Includes?"
            printvar "APACHE2_DIR_"$idx"_VIEW_DIR_CONTENT" "View files in dir if no index.html"
            printvar "APACHE2_DIR_"$idx"_WEBDAV"           "Enable WebDav"
            printvar
        fi
        idx=`expr $idx + 1`
    done
        
        
    #------------------------------------------------------------------------------
    printgroup "Virtual Hosts" ""
    #------------------------------------------------------------------------------
    printvar "APACHE2_VHOST_N"           "no. of virtual hosts"

    if [ "$APACHE2_VHOST_1_IP" != "" ]
    then
        idx='1'
        count=`expr $APACHE2_VHOST_N + 0`
    
        while [ $idx -le $count ]
        do
            printvar "APACHE2_VHOST_"$idx"_ACTIVE"                  "Should the VHost be active?"
            printvar "APACHE2_VHOST_"$idx"_IP"                      "'*' or ip address"
            printvar "APACHE2_VHOST_"$idx"_PORT"                    "Port"
            printvar "APACHE2_VHOST_"$idx"_SERVER_NAME"             "server name"
            printvar "APACHE2_VHOST_"$idx"_SERVER_ALIAS"            "server alias, may be empty"
            printvar "APACHE2_VHOST_"$idx"_SERVER_ADMIN"            "email of webmaster"
            printvar "APACHE2_VHOST_"$idx"_DOCUMENT_ROOT"           "document root"
            printvar "APACHE2_VHOST_"$idx"_SCRIPT_ALIAS"            "script alias"
            printvar "APACHE2_VHOST_"$idx"_SCRIPT_DIR"              "directory to use"
            printvar "APACHE2_VHOST_"$idx"_ERROR_LOG"               "error log"
            printvar "APACHE2_VHOST_"$idx"_ACCESS_LOG"              "access log"
            printvar "APACHE2_VHOST_"$idx"_ACCESS_CONTROL_TYPE_ALL" "Default setting is yes. Access ist granted for all"
            printvar "APACHE2_VHOST_"$idx"_ACCESS_CONTROL_TYPE_IP"  "If set to yes, access is controlled via IPADDRESS and/or NETWORK"
            printvar "APACHE2_VHOST_"$idx"_ACCESS_CONTROL_TYPE_HOST" "If set to yes, access is controlled via HOSTNAME"
            printvar "APACHE2_VHOST_"$idx"_ACCESS_CONTROL_TYPE_LOCAL" "If set to yes, only localhost has access"
            printvar "APACHE2_VHOST_"$idx"_ACCESS_CONTROL_IP"       ""
            printvar "APACHE2_VHOST_"$idx"_ACCESS_CONTROL_HOST"     ""
            printvar "APACHE2_VHOST_"$idx"_VIEW_DIRECTORY_CONTENT"  ""
            printvar "APACHE2_VHOST_"$idx"_ENABLE_SSI"              ""
            printvar "APACHE2_VHOST_"$idx"_MOD_CACHE"               "Enable mod_cache for current vhost"
            printvar "APACHE2_VHOST_"$idx"_DIR_N"                   ""
            dirIdx='1'
            eval tmpDir='$APACHE2_VHOST_'$idx'_DIR_N'
            countDir=`expr $tmpDir + 1`
    
            while [ $dirIdx -le $countDir ]
            do
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ACTIVE"           ""
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ALIAS"            "Create an alias?"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ALIAS_NAME"       "Name of alias"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_PATH"             "Name of 1. dir"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_AUTH_NAME"        "Name of the area to protect"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_AUTH_TYPE"        "Authentication type: Basic or Digest"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_AUTH_N"           "No. of usernames"
                authIdx='1'
                eval tmpAuth='$APACHE2_VHOST_'$idx'_DIR_'$dirIdx'_AUTH_N'
                countAuth=`expr $tmpAuth + 1`
    
                while [ $authIdx -le $countAuth ]
                do
                    printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_AUTH_"$authIdx"_USER"      ""
                    printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_AUTH_"$authIdx"_PASS"      ""
                    authIdx=`expr $authIdx + 1`
                done
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ACCESS_CONTROL_TYPE_ALL" "Default setting is yes. Access ist granted for all"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ACCESS_CONTROL_TYPE_IP"  "If set to yes, access is controlled via IPADDRESS and/or NETWORK"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ACCESS_CONTROL_TYPE_HOST" "If set to yes, access is controlled via HOSTNAME"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ACCESS_CONTROL_TYPE_LOCAL" "If set to yes, only localhost has access"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ACCESS_CONTROL_IP"       ""
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_ACCESS_CONTROL_HOST"     ""
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_CGI"              "!NOT YES! Possibilities are: 'none' '.pl' '.cgi'"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_SSI"              "Allow Server Side Includes?"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_VIEW_DIR_CONTENT" "View files in dir if no index.html"
                printvar "APACHE2_VHOST_"$idx"_DIR_"$dirIdx"_WEBDAV"           "Enable WebDav"
                dirIdx=`expr $dirIdx + 1`
            done
            printvar "APACHE2_VHOST_"$idx"_SSL"                   "activate SSL"
            printvar "APACHE2_VHOST_"$idx"_SSL_PORT"              "activate SSL"
            printvar "APACHE2_VHOST_"$idx"_SSL_USESTS"            "activate STS"
            printvar "APACHE2_VHOST_"$idx"_SSL_USESTS_SUBDOMAINS" "activate STS for subdomains"
            printvar "APACHE2_VHOST_"$idx"_SSL_FORCE"             "redirect to https://"
            printvar "APACHE2_VHOST_"$idx"_SSL_CERT_NAME"         "Name of the cert."

            idx=`expr $idx + 1`
        done
    fi

    # ----------------------------------------------------------------------
    printgroup "Log-file handling"
    # ----------------------------------------------------------------------
    printvar "APACHE2_LOG_LEVEL"              "warning level"
    printvar "APACHE2_LOG_COUNT"              "number of log files to save"
    printvar "APACHE2_LOG_INTERVAL"           "logrotate interval: daily, weekly, monthly"

    #----------------------------------------------------------------------------
    printgroup "Settings for performance tuning"
    #----------------------------------------------------------------------------
    printvar "APACHE2_MAX_KEEP_ALIVE_TIMEOUT"  ""
    printvar "APACHE2_MAX_KEEP_ALIVE_REQUESTS" ""
    printvar "APACHE2_MAX_CLIENTS"             ""
    printvar "APACHE2_MAX_REQUESTS_PER_CHILD"  ""

    #----------------------------------------------------------------------------
    printgroup "Settings for apache modules"
    #----------------------------------------------------------------------------
    printvar "APACHE2_MOD_CACHE"               "Enable mod_cache for APACHE2_DOCUMENT_ROOT"
    printvar "APACHE2_MOD_COMPAT"               "Enable mod_compat for compatibility with old directives"

    #------------------------------------------------------------------------------
    printgroup "Settings for Header"
    #------------------------------------------------------------------------------
    printvar "APACHE2_HEADER_NOSNIFF"        "Set X-Content-Type-Options nosniff"
    printvar "APACHE2_HEADER_XSSPROTECTION"  "set X-Xss-Protection"
    printvar "APACHE2_HEADER_SAMEORIGIN"     "X-Frame-Options SAMEORIGIN"

    #------------------------------------------------------------------------------
    printgroup "End of Apache2 Configuraton"
    #------------------------------------------------------------------------------

    #------------------------------------------------------------------------------
    printend
    #------------------------------------------------------------------------------

    ) > ${internal_conf_file}
    # Set rights
    chmod 0644 ${internal_conf_file}
    chown root ${internal_conf_file}
}

### -------------------------------------------------------------------------
### Create the check.d file
### -------------------------------------------------------------------------
make_check_file()
{
    printgpl -check "$packages_name" "$datum_creation" "schlotze" "2008-2010 Sebastian Scholze <sebastian@eisfair.org>" > /etc/check.d/${packages_name}
    cat >/etc/check.d/${packages_name} <<EOF_INT
# Variable                                         OPT_VARIABLE                                      VARIABLE_N                  VALUE
START_APACHE2                                      -                                                 -                           YESNO
APACHE2_PORT                                       START_APACHE2                                     -                           NUMERIC
APACHE2_MPM                                        START_APACHE2                                     -                           APACHE2_MPM
APACHE2_SERVER_ADMIN                               START_APACHE2                                     -                           MAILADDR
APACHE2_SERVER_NAME                                START_APACHE2                                     -                           EFQDN
APACHE2_SERVER_SIGNATURE                           START_APACHE2                                     -                           APACHE2_SERVER_SIGNATURE
APACHE2_DOCUMENT_ROOT                              START_APACHE2                                     -                           ABS_PATH
APACHE2_DIRECTORY_INDEX                            START_APACHE2                                     -                           NONE
APACHE2_HOSTNAME_LOOKUPS                           START_APACHE2                                     -                           YESNO
APACHE2_VIEW_DIRECTORY_CONTENT                     START_APACHE2                                     -                           YESNO
APACHE2_ACCESS_CONTROL_TYPE_ALL                    START_APACHE2                                     -                           YESNO
APACHE2_ACCESS_CONTROL_TYPE_IP                     !APACHE2_ACCESS_CONTROL_TYPE_ALL                  -                           YESNO
APACHE2_ACCESS_CONTROL_TYPE_HOST                   !APACHE2_ACCESS_CONTROL_TYPE_IP                   -                           YESNO
APACHE2_ACCESS_CONTROL_TYPE_LOCAL                  !APACHE2_ACCESS_CONTROL_TYPE_HOST                 -                           YESNO
APACHE2_ACCESS_CONTROL_IP                          APACHE2_ACCESS_CONTROL_TYPE_IP                    -                           IPADDR_NETWORK
APACHE2_ACCESS_CONTROL_HOST                        APACHE2_ACCESS_CONTROL_TYPE_HOST                  -                           HOSTNAME
APACHE2_ENABLE_SSI                                 START_APACHE2                                     -                           YESNO
APACHE2_ENABLE_HTTP2                               START_APACHE2                                     -                           YESNO
APACHE2_ERROR_LOG                                  START_APACHE2                                     -                           ABS_PATH
APACHE2_ACCESS_LOG                                 START_APACHE2                                     -                           ABS_PATH
APACHE2_SCRIPT_ALIAS                               START_APACHE2                                     -                           ABS_PATH
APACHE2_SCRIPT_DIR                                 START_APACHE2                                     -                           ABS_PATH
APACHE2_ERROR_DOCUMENT_N                           START_APACHE2                                     -                           NUMERIC
APACHE2_ERROR_DOCUMENT_%_ERROR                     START_APACHE2                                     APACHE2_ERROR_DOCUMENT_N    NUMERIC
APACHE2_ERROR_DOCUMENT_%_DOCUMENT                  START_APACHE2                                     APACHE2_ERROR_DOCUMENT_N    NONE
APACHE2_DIR_N                                      START_APACHE2                                     -                           NUMERIC
APACHE2_DIR_%_ACTIVE                               START_APACHE2                                     APACHE2_DIR_N               YESNO
APACHE2_DIR_%_ALIAS                                APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               YESNO
APACHE2_DIR_%_ALIAS_NAME                           APACHE2_DIR_%_ALIAS                               APACHE2_DIR_N               E_ABS_PATH
APACHE2_DIR_%_PATH                                 APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               ABS_PATH
APACHE2_DIR_%_AUTH_NAME                            APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               NONE
APACHE2_DIR_%_AUTH_TYPE                            APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               APACHE2_DIR_AUTH_TYPE
APACHE2_DIR_%_AUTH_N                               APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               NUMERIC
APACHE2_DIR_%_AUTH_%_USER                          APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_%_AUTH_N        NONE
APACHE2_DIR_%_AUTH_%_PASS                          APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_%_AUTH_N        PASSWD
APACHE2_DIR_%_CGI                                  APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               NONE
APACHE2_DIR_%_SSI                                  APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               YESNO
APACHE2_DIR_%_ACCESS_CONTROL_TYPE_ALL              APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               YESNO
APACHE2_DIR_%_ACCESS_CONTROL_TYPE_IP               !APACHE2_DIR_%_ACCESS_CONTROL_TYPE_ALL            APACHE2_DIR_N               YESNO
APACHE2_DIR_%_ACCESS_CONTROL_TYPE_HOST             !APACHE2_DIR_%_ACCESS_CONTROL_TYPE_IP             APACHE2_DIR_N               YESNO
APACHE2_DIR_%_ACCESS_CONTROL_TYPE_LOCAL            !APACHE2_DIR_%_ACCESS_CONTROL_TYPE_HOST           APACHE2_DIR_N               YESNO
APACHE2_DIR_%_ACCESS_CONTROL_IP                    APACHE2_DIR_%_ACCESS_CONTROL_TYPE_IP              APACHE2_DIR_N               APACHE2_EIPADDRNET
APACHE2_DIR_%_ACCESS_CONTROL_HOST                  APACHE2_DIR_%_ACCESS_CONTROL_TYPE_HOST            APACHE2_DIR_N               HOSTNAME
APACHE2_DIR_%_VIEW_DIR_CONTENT                     APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               YESNO
APACHE2_DIR_%_WEBDAV                               APACHE2_DIR_%_ACTIVE                              APACHE2_DIR_N               YESNO
APACHE2_SSL                                        START_APACHE2                                     -                           YESNO
APACHE2_SSL_PORT                                   APACHE2_SSL                                       -                           NUMERIC
APACHE2_SSL_LOGDIR                                 APACHE2_SSL                                       -                           ABS_PATH
APACHE2_SSL_OCSP                                   APACHE2_SSL                                       -                           YESNO
APACHE2_VHOST_N                                    START_APACHE2                                     -                           NUMERIC
APACHE2_VHOST_%_ACTIVE                             START_APACHE2                                     APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_IP                                 APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             RE:\*|(RE:IPADDR)|(RE:FQDN)
APACHE2_VHOST_%_PORT                               APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             NUMERIC
APACHE2_VHOST_%_SERVER_NAME                        APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             FQDN
APACHE2_VHOST_%_SERVER_ALIAS                       APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             NONE
APACHE2_VHOST_%_SERVER_ADMIN                       APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             MAILADDR
APACHE2_VHOST_%_DOCUMENT_ROOT                      APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             ABS_PATH
APACHE2_VHOST_%_SCRIPT_ALIAS                       APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             ABS_PATH
APACHE2_VHOST_%_SCRIPT_DIR                         APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             ABS_PATH
APACHE2_VHOST_%_ERROR_LOG                          APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             ABS_PATH
APACHE2_VHOST_%_ACCESS_LOG                         APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             ABS_PATH
APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_ALL            APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_IP             !APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_ALL          APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_HOST           !APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_IP           APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_LOCAL          !APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_HOST         APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_ACCESS_CONTROL_IP                  APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_IP            APACHE2_VHOST_N             IPADDR_NETWORK
APACHE2_VHOST_%_ACCESS_CONTROL_HOST                APACHE2_VHOST_%_ACCESS_CONTROL_TYPE_HOST          APACHE2_VHOST_N             HOSTNAME
APACHE2_VHOST_%_VIEW_DIRECTORY_CONTENT             APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_ENABLE_SSI                         APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             YESNO  
APACHE2_VHOST_%_MOD_CACHE                          APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_DIR_N                              APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             NUMERIC
APACHE2_VHOST_%_DIR_%_ACTIVE                       APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_ALIAS                        APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_ALIAS_NAME                   APACHE2_VHOST_%_DIR_%_ALIAS                       APACHE2_VHOST_%_DIR_N       E_ABS_PATH
APACHE2_VHOST_%_DIR_%_PATH                         APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       ABS_PATH
APACHE2_VHOST_%_DIR_%_AUTH_NAME                    APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       NONE
APACHE2_VHOST_%_DIR_%_AUTH_TYPE                    APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       APACHE2_DIR_AUTH_TYPE
APACHE2_VHOST_%_DIR_%_AUTH_N                       APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       NUMERIC
APACHE2_VHOST_%_DIR_%_AUTH_%_USER                  APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_%_AUTH_N NONE
APACHE2_VHOST_%_DIR_%_AUTH_%_PASS                  APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_%_AUTH_N PASSWD
APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_ALL      APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_IP       !APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_ALL    APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_HOST     !APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_IP     APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_LOCAL    !APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_HOST   APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_IP            APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_IP      APACHE2_VHOST_%_DIR_N       IPADDR_NETWORK
APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_HOST          APACHE2_VHOST_%_DIR_%_ACCESS_CONTROL_TYPE_HOST    APACHE2_VHOST_%_DIR_N       HOSTNAME
APACHE2_VHOST_%_DIR_%_CGI                          APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       NONE
APACHE2_VHOST_%_DIR_%_SSI                          APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_VIEW_DIR_CONTENT             APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_DIR_%_WEBDAV                       APACHE2_VHOST_%_DIR_%_ACTIVE                      APACHE2_VHOST_%_DIR_N       YESNO
APACHE2_VHOST_%_SSL                                APACHE2_VHOST_%_ACTIVE                            APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_SSL_PORT                           APACHE2_VHOST_%_SSL                               APACHE2_VHOST_N             NUMERIC
APACHE2_VHOST_%_SSL_USESTS                         APACHE2_VHOST_%_SSL                               APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_SSL_USESTS_SUBDOMAINS              APACHE2_VHOST_%_SSL_USESTS                        APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_SSL_FORCE                          APACHE2_VHOST_%_SSL                               APACHE2_VHOST_N             YESNO
APACHE2_VHOST_%_SSL_CERT_NAME                      APACHE2_VHOST_%_SSL                               APACHE2_VHOST_N             NOTEMPTY
APACHE2_LOG_LEVEL                                  START_APACHE2                                     -                           APACHE2_LOG_LEVEL
APACHE2_LOG_COUNT                                  START_APACHE2                                     -                           NUMERIC
APACHE2_LOG_INTERVAL                               START_APACHE2                                     -                           APACHE2_LOG_INTERVAL
APACHE2_MAX_KEEP_ALIVE_TIMEOUT                     START_APACHE2                                     -                           NUMERIC
APACHE2_MAX_KEEP_ALIVE_REQUESTS                    START_APACHE2                                     -                           NUMERIC
APACHE2_MAX_CLIENTS                                START_APACHE2                                     -                           NUMERIC
APACHE2_MAX_REQUESTS_PER_CHILD                     START_APACHE2                                     -                           NUMERIC
APACHE2_MOD_CACHE                                  START_APACHE2                                     -                           YESNO
APACHE2_MOD_COMPAT                                 START_APACHE2                                     -                           YESNO
APACHE2_HEADER_NOSNIFF                             START_APACHE2                                     -                           YESNO
APACHE2_HEADER_XSSPROTECTION                       START_APACHE2                                     -                           YESNO
APACHE2_HEADER_SAMEORIGIN                          START_APACHE2                                     -                           YESNO

EOF_INT

    # Set rights for check.d file
    chmod 0644 /etc/check.d/${packages_name}
    chown root /etc/check.d/${packages_name}

### ---------------------------------------------------------------------------
### Create the EXTENTED check.d file
### ---------------------------------------------------------------------------
    printgpl -check_exp "$packages_name" "${datum_update}" "${my_initial}" "${my_name}" > /etc/check.d/${packages_name}.exp
cat >> /etc/check.d/${packages_name}.exp << EOF
APACHE2_LOG_LEVEL        = 'debug|info|notice|warn|error|crit|alert|emerg'
                          : 'no valid level, should be debug, info, notice, warn, error, crit, alert or emerg'
APACHE2_LOG_INTERVAL     = 'daily|weekly|monthly'
                          : 'no valid interval, should be daily, weekly or monthly'
APACHE2_SERVER_SIGNATURE = 'On|Off|Email'
                          : 'only on, off or email is allowd'
APACHE2_DIR_AUTH_TYPE    = 'Basic|Digest'
                          : 'only Basic or Digest is allowd'
APACHE2_EIPADDRNET       = '(RE:IPADDR_NETWORK)(( *(RE:IPADDR_NETWORK))+)?'
                          : 'no valid address entry, should be one or more ip addresses or networks separated by whitespaces'
APACHE2_MPM              = 'prefork|event|worker'
                          : 'only prefork or event is allowd'
EOF
    # Set rights for check.exp file
    chmod 0644 /etc/check.d/${packages_name}.exp
    chown root /etc/check.d/${packages_name}.exp
}

### ---------------------------------------------------------------------------
### Main
### ---------------------------------------------------------------------------

# write default config file
make_config_file /etc/default.d/${packages_name}

# Der erste Beispiel VHost soll nur waehrend der Installation angelegt werden und dann auch nur, wenn noch keine Konfigurationsdatei existiert. Waere dieser Scriptblock nicht da, koennte man den ersten VHost nie entfernen
if [ ! -f /tmp/apache-install.lock ]
then
    vhost_n_old=$APACHE2_VHOST_N

    APACHE2_VHOST_N='1'
    unset_vhost_vars

    APACHE2_VHOST_N=$vhost_n_old
fi

# update from old version
if [ -f /etc/config.d/$packages_name ]
then
    rename_old_variables
    remove_old_modules
    remove_old_module_configs
fi

add_variables

# write new config file
make_config_file /etc/config.d/${packages_name}

# write check.d file
make_check_file

### ---------------------------------------------------------------------------
### end
### ---------------------------------------------------------------------------
